#[repr(C)]pub enum GaussianPreciseLevel {
EXACT = 0,
INTEGRAL = 1,
}Expand description
Declares requested precision level, this is supported only for u8
Variants
EXACT = 0
Exact precision, f32 accumulator and weights will be used
INTEGRAL = 1
Convolution in integral approximation, this is faster than exact convolution but may change result. Estimated error not less than 1-2%